## 1.4.0 (2022-08-26)

[stubsabot] Bump tree-sitter-languages to 1.4.* (#8623)

## 1.3.0 (2022-08-17)

Add stubs for tree-sitter-languages (#8548)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

